@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2008 Tristan Van Berkom.
  *
@@ -19,6 +18,7 @@
  * Authors:
  *   Tristan Van Berkom <tvb@gnome.org>
  */
+
 #ifndef _GLADE_STORE_EDITOR_H_
 #define _GLADE_STORE_EDITOR_H_
 
@@ -26,35 +26,33 @@
 
 G_BEGIN_DECLS
 
-#define GLADE_TYPE_STORE_EDITOR	            (glade_store_editor_get_type ())
-#define GLADE_STORE_EDITOR(obj)		    (G_TYPE_CHECK_INSTANCE_CAST ((obj), GLADE_TYPE_STORE_EDITOR, GladeStoreEditor))
-#define GLADE_STORE_EDITOR_CLASS(klass)	    (G_TYPE_CHECK_CLASS_CAST ((klass), GLADE_TYPE_STORE_EDITOR, GladeStoreEditorClass))
-#define GLADE_IS_STORE_EDITOR(obj)	    (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GLADE_TYPE_STORE_EDITOR))
-#define GLADE_IS_STORE_EDITOR_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), GLADE_TYPE_STORE_EDITOR))
-#define GLADE_STORE_EDITOR_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GLADE_TYPE_STORE_EDITOR, GladeStoreEditorClass))
+#define GLADE_TYPE_STORE_EDITOR            (glade_store_editor_get_type ())
+#define GLADE_STORE_EDITOR(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GLADE_TYPE_STORE_EDITOR, GladeStoreEditor))
+#define GLADE_STORE_EDITOR_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GLADE_TYPE_STORE_EDITOR, GladeStoreEditorClass))
+#define GLADE_IS_STORE_EDITOR(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GLADE_TYPE_STORE_EDITOR))
+#define GLADE_IS_STORE_EDITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GLADE_TYPE_STORE_EDITOR))
+#define GLADE_STORE_EDITOR_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GLADE_TYPE_STORE_EDITOR, GladeStoreEditorClass))
 
 typedef struct _GladeStoreEditor        GladeStoreEditor;
 typedef struct _GladeStoreEditorClass   GladeStoreEditorClass;
 
 struct _GladeStoreEditor
 {
-	GtkVBox  parent;
+  GtkBox  parent;
 
-	GladeWidget *loaded_widget; /* A handy pointer to the loaded widget ... */
+  GtkWidget *embed;
 
-	GtkWidget *embed;
-
-	GList *properties;         /* A list of eprops to update at load() time */
+  GList *properties;         /* A list of eprops to update at load() time */
 };
 
 struct _GladeStoreEditorClass
 {
-	GtkVBoxClass parent;
+  GtkBoxClass parent;
 };
 
 GType            glade_store_editor_get_type (void) G_GNUC_CONST;
 GtkWidget       *glade_store_editor_new      (GladeWidgetAdaptor *adaptor,
-					      GladeEditable      *editable);
+                                              GladeEditable      *editable);
 
 G_END_DECLS
 
